@@ -6,18 +6,20 @@
 #' @param env Indicator of the experiment or the intervention type an 
 #' observation belongs to (a numeric vector of length n).
 #' @param whichEnv Indicator for the environment to be plotted.
-#'  
-plotDiagonalization <- function(estConnectivity, X, env, whichEnv){
+#' @param main Optional title for plot; defaults to paste("Env.", whichEnv)
+#'
+plotDiagonalization <- function(estConnectivity, X, env, whichEnv, main = NULL){
   deltas <- computeDelta(X, env)$Delta
   p <- ncol(estConnectivity)
   K <- length(deltas)
-  
+  settings <- sort(unique(env))
   deltaIntVar <- vector("list", K)
   
-  tmp <- (diag(p) - t(estConnectivity))%*%deltas[[whichEnv]]%*%t(diag(p) - t(estConnectivity))
+  tmp <- (diag(p) - t(estConnectivity))%*%deltas[[which(settings == whichEnv)]]%*%t(diag(p) - t(estConnectivity))
   deltaIntVar <- abs(tmp)/max(abs(tmp))
   
+  if(is.null(main)) paste("Env.", whichEnv) else main
+  
   fields::image.plot(z = deltaIntVar, col=fields::tim.colors(), legend.shrink = 0.8,
-                     main = paste("Env.", whichEnv))
-
+                     main = main)
 }
